#
# spec file for package python-pydata-google-auth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pydata-google-auth
Version:        1.8.2
Release:        2.3
Summary:        PyData helpers for authenticating to Google APIs
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/pydata/pydata-google-auth
Source:         https://github.com/pydata/pydata-google-auth/archive/%{version}.tar.gz#/pydata-google-auth-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/pydata/pydata-google-auth/pull/73 Do not require six on Python 3
Patch0:         no-six.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module versioneer}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-auth >= 1.25.1
Requires:       python-google-auth-oauthlib >= 0.4.0
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module google-auth >= 1.25.0}
BuildRequires:  %{python_module google-auth-oauthlib >= 0.4.0}
BuildRequires:  %{python_module pyfakefs}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
PyData-Google-Auth is a package providing helpers for authenticating
to Google APIs.

%prep
%autosetup -p1 -n pydata-google-auth-%{version}
rm versioneer.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests/unit

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/pydata_google_auth
%{python_sitelib}/pydata_google_auth-%{version}.dist-info

%changelog
* Fri Mar 22 2024 Ben Greiner <code@bnavigator.de>
- Remove ancient versioneer.py and use system one for Python 3.12
  compatibility -- gh#pydata/pydata-google-auth#74
* Thu Oct 19 2023 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Thu Oct 19 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.8.2
  * Adds pydata_google_auth.load_service_account_credentials() function to get
    service account credentials from the specified JSON path.
  * Adds support for Python 3.10.
  * Default use_local_webserver to True.
  * Adds ability to provide redirect uri.
  * Adds decision logic to handle use cases where a user may not have the ability
    to log in via an Out of Band authentication flow.
  * Add optional colab specific ADC
- Add no-six.patch to get rid of six dependency
  * with backwards compatibility for the upstream
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.1.0
  * Try a range of ports between 8080 and 8090 when ``use_local_webserver`` is
    ``True``. (:issue:`35`)
  * Mark package as 1.0, generally available.
  * Update introduction with link to instructions on creating a Google Cloud
    project. (:issue:`18`)
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.3.0
  * Add python -m pydata_google_auth CLI for working with user credentials
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.2.1
  * Re-enable ``auth_local_webserver`` in ``default`` method. Show warning,
    rather than fallback to console.
- Update to 0.2.0
  + Deprecations
  * **Deprecate** ``auth_local_webserver`` argument in favor of
    ``use_local_webserver`` argument
  + New Features
  * Adds :func:`pydata_google_auth.save_user_credentials` function to get user
    credentials and then save them to a specified JSON path.
  + Bug Fixes
  * Update OAuth2 token endpoint to latest URI from Google.
  * Don't raise error when the ``APPDATA`` environment variable isn't set on
    Windows.
* Mon Jul 22 2019 Todd R <toddrme2178@gmail.com>
- Initial version
